@@ -5,15 +5,16 @@ use strict;
 use warnings;
 use base qw(Test::Class);
 
+use English qw(-no_match_vars);
 use Stancer::Config;
 use Stancer::Core::Object::Stub;
 use Stancer::Core::Request;
 use LWP::UserAgent;
-use POSIX;
+use POSIX qw(floor);
 use TestCase qw(:lwp);
 use Try::Tiny;
 
-## no critic (ProhibitPunctuationVars, RequireFinalReturn, RequireInterpolationOfMetachars, RequireExtendedFormatting)
+## no critic (RequireExtendedFormatting, RequireFinalReturn, ValuesAndExpressions::RequireInterpolationOfMetachars)
 
 sub instanciate : Tests(2) {
     my $key = 'stest_' . random_string(24);
@@ -32,7 +33,7 @@ sub instanciate : Tests(2) {
 
     my $object = Stancer::Config->new(%args);
 
-    isa_ok($object, 'Stancer::Config');
+    isa_ok($object, 'Stancer::Config', 'Stancer::Config->new(%args)');
 
     cmp_deeply($object, noclass({
         calls => [],
@@ -54,16 +55,16 @@ sub calls : Tests(18) {
     { # 8 tests
         note 'Without exception';
 
-        isa_ok($config->calls, 'ARRAY', 'Should return an ARRAY');
+        isa_ok($config->calls, 'ARRAY', '$config->calls');
         is(scalar @{ $config->calls }, 0, 'Should be empty');
 
         $mock_ua->clear();
 
         $request->get($object);
 
-        isa_ok($config->calls, 'ARRAY', 'Should still return an ARRAY');
+        isa_ok($config->calls, 'ARRAY', '$config->calls');
         is(scalar @{ $config->calls }, 1, 'Should have one call registered');
-        isa_ok($config->calls->[0], 'Stancer::Core::Request::Call', 'That should contain a call instance');
+        isa_ok($config->calls->[0], 'Stancer::Core::Request::Call', '$config->calls->[0]');
 
         is($config->calls->[0]->request, $mock_request, 'The call should have a request');
         is($config->calls->[0]->response, $mock_response, 'The call should have a response');
@@ -73,21 +74,21 @@ sub calls : Tests(18) {
     { # 10 tests
         note 'With exception';
 
-        isa_ok($config->calls, 'ARRAY', 'Should return an ARRAY');
+        isa_ok($config->calls, 'ARRAY', '$config->calls');
         is(scalar @{ $config->calls }, 1, 'Should still have previous call');
 
         $mock_ua->clear();
-        $mock_response->set_false(qw/is_success/);
+        $mock_response->set_false(qw(is_success));
         $mock_response->set_always(decoded_content => undef);
         $mock_response->set_always(code => 409);
 
         throws_ok(sub { $request->get($object) }, 'Stancer::Exceptions::Http::Conflict', 'This one was expected');
 
-        my $exception = $@; ## no critic (ProhibitPunctuationVars)
+        my $exception = $EVAL_ERROR;
 
-        isa_ok($config->calls, 'ARRAY', 'Should still return an ARRAY');
+        isa_ok($config->calls, 'ARRAY', '$config->calls');
         is(scalar @{ $config->calls }, 2, 'Should have one more call registered');
-        isa_ok($config->calls->[1], 'Stancer::Core::Request::Call', 'That should contain a call instance');
+        isa_ok($config->calls->[1], 'Stancer::Core::Request::Call', '$config->calls->[1]');
 
         is($config->calls->[1]->request, $mock_request, 'The call should have a request');
         is($config->calls->[1]->response, $mock_response, 'The call should have a response');
@@ -139,12 +140,12 @@ sub default_timezone : Tests(5) {
 
     $object->default_timezone($tz);
 
-    isa_ok($object->default_timezone, 'DateTime::TimeZone', 'Should be updated with a TimeZone');
+    isa_ok($object->default_timezone, 'DateTime::TimeZone', '$config->default_timezone');
     is($object->default_timezone, $tz, 'Should be the same instance');
 
     $object->default_timezone('Europe/Paris');
 
-    isa_ok($object->default_timezone, 'DateTime::TimeZone', 'Should be updated with a TimeZone');
+    isa_ok($object->default_timezone, 'DateTime::TimeZone', '$config->default_timezone');
     cmp_deeply($object->default_timezone, $tz, 'Should be equal to a new instance');
 }
 
@@ -307,7 +308,7 @@ sub keychain : Tests(47) {
         foreach my $key (@keys) {
             my @filtered = grep { $_ eq $key } @{$keys};
 
-            ok(scalar @filtered, 'Should have ' . $key . ' key');
+            ok(scalar @filtered, 'Should have "' . $key . '" key');
         }
     }
 
@@ -334,7 +335,7 @@ sub keychain : Tests(47) {
         foreach my $key (@keys) {
             my @filtered = grep { $_ eq $key } @{$keys};
 
-            ok(scalar @filtered, 'Should have ' . $key . ' key');
+            ok(scalar @filtered, 'Should have "' . $key . '" key');
         }
     }
 
@@ -351,20 +352,20 @@ sub keychain : Tests(47) {
 
         isa_ok($keys, 'ARRAY', 'Stancer::Config->new->keychain($key)');
         is(scalar @{$keys}, 1, 'Should have only one element');
-        is($keys->[0], $key, 'Should be ' . $key);
+        is($keys->[0], $key, 'Should be "' . $key . '"');
     }
 
     my @invalid = (
-        random_string(30), # bad prefix
-        'ptest_' . random_string(10), # too small
-        'ptest_' . random_string(30), # too long
+        [random_string(30), 'unknown prefix'],
+        ['ptest_' . random_string(10), 'too small'],
+        ['ptest_' . random_string(30), 'too long'],
     );
 
     my $not_valid = 'is not a valid API key';
     my $object = Stancer::Config->new();
 
-    foreach my $key (@invalid) {
-        throws_ok { $object->keychain($key) } qr/"$key" $not_valid/sm, 'Invalid key ' . $key;
+    foreach my $data (@invalid) {
+        throws_ok { $object->keychain($data->[0]) } qr/"$data->[0]" $not_valid/sm, 'Invalid key ' . $data->[1];
     }
 }
 
@@ -372,7 +373,7 @@ sub lwp : Tests(2) {
     my $object = Stancer::Config->new();
     my $default = $object->lwp;
 
-    isa_ok($default, 'LWP::UserAgent', 'Should return a valid instance of LWP::UserAgent by default');
+    isa_ok($default, 'LWP::UserAgent', '$config->lwp');
 
     my $ua = LWP::UserAgent->new();
 
@@ -400,7 +401,7 @@ sub mode : Tests(5) {
     throws_ok {
         $object->mode($invalid);
     } 'Stancer::Exceptions::InvalidArgument', 'Should emit an exception';
-    is($@->message, sprintf($message, q/"/ . $invalid . q/"/), 'Message check');
+    is($EVAL_ERROR->message, sprintf($message, q/"/ . $invalid . q/"/), 'Message check');
 }
 
 sub port : Tests(2) {
@@ -418,12 +419,12 @@ sub pprod : Tests(8) {
     my $object = Stancer::Config->new();
     my $key = 'pprod_' . random_string(24);
     my @invalid = (
-        'sprod_' . random_string(24),
-        'ptest_' . random_string(24),
-        'stest_' . random_string(24),
-        random_string(30), # bad prefix
-        'pprod_' . random_string(10), # too small
-        'pprod_' . random_string(30), # too long
+        ['sprod_' . random_string(24), '"sprod" not a "pprod"'],
+        ['ptest_' . random_string(24), '"ptest" not a "pprod"'],
+        ['stest_' . random_string(24), '"stest" not a "pprod"'],
+        [random_string(30), 'unknown prefix' ],
+        ['pprod_' . random_string(10), 'too small' ],
+        ['pprod_' . random_string(30), 'too long' ],
     );
 
     is($object->pprod, undef, 'Undefined by default');
@@ -434,8 +435,8 @@ sub pprod : Tests(8) {
 
     my $not_valid = 'is not a valid public API key for live mode';
 
-    foreach my $key (@invalid) {
-        throws_ok { $object->pprod($key) } qr/"$key" $not_valid/sm, 'Invalid key ' . $key;
+    foreach my $data (@invalid) {
+        throws_ok { $object->pprod($data->[0]) } qr/"$data->[0]" $not_valid/sm, 'Invalid key, ' . $data->[1];
     }
 }
 
@@ -445,13 +446,25 @@ sub public_key : Tests(6) {
 
         my $object = Stancer::Config->new();
 
-        throws_ok { $object->public_key } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (dev)';
-        is($@->message, 'You did not provide valid public API key for development.', 'Should indicate the error (dev)');
+        throws_ok {
+            $object->public_key
+        } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (dev)';
+        is(
+            $EVAL_ERROR->message,
+            'You did not provide valid public API key for development.',
+            'Should indicate the error (dev)',
+        );
 
         $object->mode('live');
 
-        throws_ok { $object->public_key } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (prod)';
-        is($@->message, 'You did not provide valid public API key for production.', 'Should indicate the error (prod)');
+        throws_ok {
+            $object->public_key
+        } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (prod)';
+        is(
+            $EVAL_ERROR->message,
+            'You did not provide valid public API key for production.',
+            'Should indicate the error (prod)',
+        );
     }
 
     { # 2 tests
@@ -475,12 +488,12 @@ sub ptest : Tests(8) {
     my $object = Stancer::Config->new();
     my $key = 'ptest_' . random_string(24);
     my @invalid = (
-        'pprod_' . random_string(24),
-        'sprod_' . random_string(24),
-        'stest_' . random_string(24),
-        random_string(30), # bad prefix
-        'ptest_' . random_string(10), # too small
-        'ptest_' . random_string(30), # too long
+        ['pprod_' . random_string(24), '"pprod" is not a "ptest"'],
+        ['sprod_' . random_string(24), '"sprod" is not a "ptest"'],
+        ['stest_' . random_string(24), '"stest" is not a "ptest"'],
+        [random_string(30), 'unknown prefix'],
+        ['ptest_' . random_string(10), 'too small'],
+        ['ptest_' . random_string(30), 'too long'],
     );
 
     is($object->ptest, undef, 'Undefined by default');
@@ -491,8 +504,8 @@ sub ptest : Tests(8) {
 
     my $not_valid = 'is not a valid public API key for test mode';
 
-    foreach my $key (@invalid) {
-        throws_ok { $object->ptest($key) } qr/"$key" $not_valid/sm, 'Invalid key ' . $key;
+    foreach my $data (@invalid) {
+        throws_ok { $object->ptest($data->[0]) } qr/"$data->[0]" $not_valid/sm, 'Invalid key ' . $data->[1];
     }
 }
 
@@ -502,13 +515,25 @@ sub secret_key : Tests(6) {
 
         my $object = Stancer::Config->new();
 
-        throws_ok { $object->secret_key } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (dev)';
-        is($@->message, 'You did not provide valid secret API key for development.', 'Should indicate the error (dev)');
+        throws_ok {
+            $object->secret_key
+        } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (dev)';
+        is(
+            $EVAL_ERROR->message,
+            'You did not provide valid secret API key for development.',
+            'Should indicate the error (dev)',
+        );
 
         $object->mode('live');
 
-        throws_ok { $object->secret_key } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (prod)';
-        is($@->message, 'You did not provide valid secret API key for production.', 'Should indicate the error (prod)');
+        throws_ok {
+            $object->secret_key
+        } 'Stancer::Exceptions::MissingApiKey', 'Should complain if no key available (prod)';
+        is(
+            $EVAL_ERROR->message,
+            'You did not provide valid secret API key for production.',
+            'Should indicate the error (prod)',
+        );
     }
 
     { # 2 tests
@@ -532,12 +557,12 @@ sub sprod : Tests(8) {
     my $object = Stancer::Config->new();
     my $key = 'sprod_' . random_string(24);
     my @invalid = (
-        'pprod_' . random_string(24),
-        'ptest_' . random_string(24),
-        'stest_' . random_string(24),
-        random_string(30), # bad prefix
-        'sprod_' . random_string(10), # too small
-        'sprod_' . random_string(30), # too long
+        ['pprod_' . random_string(24), '"pprod" is not a "sprod"'],
+        ['ptest_' . random_string(24), '"ptest" is not a "sprod"'],
+        ['stest_' . random_string(24), '"stest" is not a "sprod"'],
+        [random_string(30), 'unknown prefix'],
+        ['sprod_' . random_string(10), 'too small'],
+        ['sprod_' . random_string(30), 'too long'],
     );
 
     is($object->sprod, undef, 'Undefined by default');
@@ -548,8 +573,8 @@ sub sprod : Tests(8) {
 
     my $not_valid = 'is not a valid secret API key for live mode';
 
-    foreach my $key (@invalid) {
-        throws_ok { $object->sprod($key) } qr/"$key" $not_valid/sm, 'Invalid key ' . $key;
+    foreach my $data (@invalid) {
+        throws_ok { $object->sprod($data->[0]) } qr/"$data->[0]" $not_valid/sm, 'Invalid key ' . $data->[1];
     }
 }
 
@@ -557,12 +582,12 @@ sub stest : Tests(8) {
     my $object = Stancer::Config->new();
     my $key = 'stest_' . random_string(24);
     my @invalid = (
-        'pprod_' . random_string(24),
-        'ptest_' . random_string(24),
-        'sprod_' . random_string(24),
-        random_string(30), # bad prefix
-        'stest_' . random_string(10), # too small
-        'stest_' . random_string(30), # too long
+        ['pprod_' . random_string(24), '"pprod" is not a "stest"'],
+        ['ptest_' . random_string(24), '"ptest" is not a "stest"'],
+        ['sprod_' . random_string(24), '"sprod" is not a "stest"'],
+        [random_string(30), 'unknown prefix'],
+        ['stest_' . random_string(10), 'too small'],
+        ['stest_' . random_string(30), 'too long'],
     );
 
     is($object->stest, undef, 'Undefined by default');
@@ -573,8 +598,8 @@ sub stest : Tests(8) {
 
     my $not_valid = 'is not a valid secret API key for test mode';
 
-    foreach my $key (@invalid) {
-        throws_ok { $object->stest($key) } qr/"$key" $not_valid/sm, 'Invalid key ' . $key;
+    foreach my $data (@invalid) {
+        throws_ok { $object->stest($data->[0]) } qr/"$data->[0]" $not_valid/sm, 'Invalid key ' . $data->[1];
     }
 }
 
@@ -582,7 +607,7 @@ sub timeout : Tests(2) {
     my $object = Stancer::Config->new();
     my $timeout = floor(rand 100) * 100;
 
-    is($object->timeout, 5, '5 by default');
+    is($object->timeout, undef, '`undef` by default');
 
     $object->timeout($timeout);
 
