@@ -14,10 +14,10 @@ use TestCase;
 sub instance : Tests(7) {
     my $object = Stancer::Exceptions::Http::Conflict->new();
 
-    isa_ok($object, 'Stancer::Exceptions::Http::Conflict', 'Should return current instance');
-    isa_ok($object, 'Stancer::Exceptions::Http::ClientSide', 'Should be a client side exception');
-    isa_ok($object, 'Stancer::Exceptions::Http', 'Should be an HTTP exception');
-    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Should be throwable');
+    isa_ok($object, 'Stancer::Exceptions::Http::Conflict', 'Stancer::Exceptions::Http::Conflict->new()');
+    isa_ok($object, 'Stancer::Exceptions::Http::ClientSide', 'Stancer::Exceptions::Http::Conflict->new()');
+    isa_ok($object, 'Stancer::Exceptions::Http', 'Stancer::Exceptions::Http::Conflict->new()');
+    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Stancer::Exceptions::Http::Conflict->new()');
 
     is($object->message, 'Conflict', 'Has default message');
     is($object->log_level, 'error', 'Has a log level');
