@@ -14,10 +14,10 @@ use TestCase;
 sub instance : Tests(7) {
     my $object = Stancer::Exceptions::Http::InternalServerError->new();
 
-    isa_ok($object, 'Stancer::Exceptions::Http::InternalServerError', 'Should return current instance');
-    isa_ok($object, 'Stancer::Exceptions::Http::ServerSide', 'Should be a server side exception');
-    isa_ok($object, 'Stancer::Exceptions::Http', 'Should be an HTTP exception');
-    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Should be throwable');
+    isa_ok($object, 'Stancer::Exceptions::Http::InternalServerError', 'Stancer::Exceptions::Http::InternalServerError->new()');
+    isa_ok($object, 'Stancer::Exceptions::Http::ServerSide', 'Stancer::Exceptions::Http::InternalServerError->new()');
+    isa_ok($object, 'Stancer::Exceptions::Http', 'Stancer::Exceptions::Http::InternalServerError->new()');
+    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Stancer::Exceptions::Http::InternalServerError->new()');
 
     is($object->message, 'Internal Server Error', 'Has default message');
     is($object->log_level, 'critical', 'Has a log level');
