@@ -14,8 +14,8 @@ use TestCase;
 sub instance : Tests(4) {
     my $object = Stancer::Exceptions::InvalidArgument->new();
 
-    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Should return current instance');
-    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Should be throwable');
+    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Stancer::Exceptions::InvalidArgument->new()');
+    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Stancer::Exceptions::InvalidArgument->new()');
 
     is($object->message, 'Invalid argument.', 'Has default message');
     is($object->log_level, 'notice', 'Has a log level');
