@@ -14,9 +14,9 @@ use TestCase;
 sub instance : Tests(5) {
     my $object = Stancer::Exceptions::InvalidCardNumber->new();
 
-    isa_ok($object, 'Stancer::Exceptions::InvalidCardNumber', 'Should return current instance');
-    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Should be an invalid argument exception too');
-    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Should be throwable');
+    isa_ok($object, 'Stancer::Exceptions::InvalidCardNumber', 'Stancer::Exceptions::InvalidCardNumber->new()');
+    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Stancer::Exceptions::InvalidCardNumber->new()');
+    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Stancer::Exceptions::InvalidCardNumber->new()');
 
     is($object->message, 'Invalid card number.', 'Has default message');
     is($object->log_level, 'debug', 'Has a log level');
