@@ -14,10 +14,10 @@ use TestCase;
 sub instance : Tests(6) {
     my $object = Stancer::Exceptions::InvalidSearchCreation->new();
 
-    isa_ok($object, 'Stancer::Exceptions::InvalidSearchCreation', 'Should return current instance');
-    isa_ok($object, 'Stancer::Exceptions::InvalidSearchFilter', 'Should be a search filter exception');
-    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Should be an invalid argument exception too');
-    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Should be throwable');
+    isa_ok($object, 'Stancer::Exceptions::InvalidSearchCreation', 'Stancer::Exceptions::InvalidSearchCreation->new()');
+    isa_ok($object, 'Stancer::Exceptions::InvalidSearchFilter', 'Stancer::Exceptions::InvalidSearchCreation->new()');
+    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Stancer::Exceptions::InvalidSearchCreation->new()');
+    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Stancer::Exceptions::InvalidSearchCreation->new()');
 
     is($object->message, 'Created must be a position integer or a DateTime object and must be in the past.', 'Has default message');
     is($object->log_level, 'debug', 'Has a log level');
