@@ -12,9 +12,9 @@ use TestCase;
 sub instance : Tests(5) {
     my $object = Stancer::Exceptions::InvalidUniqueId->new();
 
-    isa_ok($object, 'Stancer::Exceptions::InvalidUniqueId', 'Should return current instance');
-    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Should be an invalid argument exception too');
-    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Should be throwable');
+    isa_ok($object, 'Stancer::Exceptions::InvalidUniqueId', 'Stancer::Exceptions::InvalidUniqueId->new()');
+    isa_ok($object, 'Stancer::Exceptions::InvalidArgument', 'Stancer::Exceptions::InvalidUniqueId->new()');
+    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Stancer::Exceptions::InvalidUniqueId->new()');
 
     is($object->message, 'Invalid unique ID.', 'Has default message');
     is($object->log_level, 'debug', 'Has a log level');
