@@ -14,9 +14,9 @@ use TestCase;
 sub instance : Tests(5) {
     my $object = Stancer::Exceptions::MissingReturnUrl->new();
 
-    isa_ok($object, 'Stancer::Exceptions::MissingReturnUrl', 'Should return current instance');
-    isa_ok($object, 'Stancer::Exceptions::BadMethodCall', 'Should be a bad method call exception too');
-    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Should be throwable');
+    isa_ok($object, 'Stancer::Exceptions::MissingReturnUrl', 'Stancer::Exceptions::MissingReturnUrl->new()');
+    isa_ok($object, 'Stancer::Exceptions::BadMethodCall', 'Stancer::Exceptions::MissingReturnUrl->new()');
+    isa_ok($object, 'Stancer::Exceptions::Throwable', 'Stancer::Exceptions::MissingReturnUrl->new()');
 
     is($object->message, 'You must provide a return URL.', 'Has default message');
     is($object->log_level, 'critical', 'Has a log level');
