@@ -5,6 +5,7 @@ use strict;
 use warnings;
 use base qw(Test::Class);
 
+use English qw(-no_match_vars);
 use Stancer::Card;
 use Stancer::Customer;
 use Stancer::Payment;
@@ -12,7 +13,7 @@ use Stancer::Payment::Status;
 use List::Util qw(shuffle);
 use TestCase;
 
-## no critic (ProhibitPunctuationVars, RequireFinalReturn, RequireInterpolationOfMetachars, RequireExtendedFormatting)
+## no critic (RequireFinalReturn, ValuesAndExpressions::RequireInterpolationOfMetachars, RequireExtendedFormatting)
 
 sub bad_credential : Tests(3) {
     my $config = Stancer::Config->init();
@@ -24,10 +25,10 @@ sub bad_credential : Tests(3) {
     throws_ok(
         sub { Stancer::Payment->new('paym_' . random_string(24))->populate() },
         'Stancer::Exceptions::Http::Unauthorized',
-        'Should throw a Unauthorized (401) error'
+        'Should throw a Unauthorized (401) error',
     );
 
-    my $exception = $@; ## no critic (ProhibitPunctuationVars)
+    my $exception = $EVAL_ERROR;
 
     isa_ok($exception->request, 'HTTP::Request', '$exception->request');
     isa_ok($exception->response, 'HTTP::Response', '$exception->response');
@@ -40,7 +41,7 @@ sub get_data : Tests(9) {
     throws_ok(
         sub { Stancer::Payment->new('paym_' . random_string(24))->populate() },
         'Stancer::Exceptions::Http::NotFound',
-        'Should throw a NotFound (404) error'
+        'Should throw a NotFound (404) error',
     );
 
     my $payment = Stancer::Payment->new('paym_FQgpGVJpyGPVJVIuQtO3zy6i');
@@ -50,10 +51,10 @@ sub get_data : Tests(9) {
     is($payment->description, 'Automatic test, 78.10 USD', 'Should have a description');
     is($payment->method, 'card', 'Should have a method');
 
-    isa_ok($payment->card, 'Stancer::Card', 'Should have a card');
+    isa_ok($payment->card, 'Stancer::Card', '$payment->card');
     is($payment->card->id, 'card_nsA0eap90E6HRod6j54pnVWg', 'Card should have an id');
 
-    isa_ok($payment->customer, 'Stancer::Customer', 'Should have a customer');
+    isa_ok($payment->customer, 'Stancer::Customer', '$payment->customer');
     is($payment->customer->id, 'cust_6FbQaYtxjADzerqdO5gs79as', 'Customer should have an id');
 }
 
@@ -83,7 +84,13 @@ sub list : Tests(38) {
         $payment1->currency($currencies[0]);
         $payment1->description($description1);
         $payment1->card($card1);
-        $payment1->customer(Stancer::Customer->new(name => 'John Doe', email => 'john.doe+' . random_string(5) . '@example.com', external_id => random_string(20)));
+        $payment1->customer(
+            Stancer::Customer->new(
+                name => 'John Doe',
+                email => 'john.doe+' . random_string(5) . '@example.com',
+                external_id => random_string(20),
+            ),
+        );
         $payment1->order_id($order_id);
 
         $payment1->send();
@@ -106,7 +113,13 @@ sub list : Tests(38) {
         $payment2->currency($currencies[1]);
         $payment2->description($description2);
         $payment2->card($card2);
-        $payment2->customer(Stancer::Customer->new(name => 'John Doe', email => 'john.doe+' . random_string(5) . '@example.com', external_id => random_string(20)));
+        $payment2->customer(
+            Stancer::Customer->new(
+                name => 'John Doe',
+                email => 'john.doe+' . random_string(5) . '@example.com',
+                external_id => random_string(20),
+            ),
+        );
         $payment2->order_id($order_id);
 
         $payment2->send();
@@ -116,14 +129,14 @@ sub list : Tests(38) {
         my $list = Stancer::Payment->list({order_id => $order_id});
         my $index = 0;
 
-        isa_ok($list, 'Stancer::Core::Iterator::Payment', 'Should return a Payment iterator');
+        isa_ok($list, 'Stancer::Core::Iterator::Payment', 'Stancer::Payment->list({order_id => $order_id})');
 
         while (my $payment = $list->next()) {
             my $sent = $payments[$index];
 
             $index++;
 
-            isa_ok($payment, 'Stancer::Payment', 'Should return a payment object (payment ' . $index . q/)/);
+            isa_ok($payment, 'Stancer::Payment', '$list->next() (payment ' . $index . q/)/);
 
             is($payment->id, $sent->id, 'Should have same id (payment ' . $index . q/)/);
             is($payment->amount, $sent->amount, 'Should have same amount (payment ' . $index . q/)/);
@@ -132,9 +145,21 @@ sub list : Tests(38) {
             is($payment->order_id, $sent->order_id, 'Should have same order_id (payment ' . $index . q/)/);
 
             is($payment->customer->id, $sent->customer->id, 'Customer should have same id (payment ' . $index . q/)/);
-            is($payment->customer->email, $sent->customer->email, 'Customer should have same email (payment ' . $index . q/)/);
-            is($payment->customer->external_id, $sent->customer->external_id, 'Customer should have same external_id (payment ' . $index . q/)/);
-            is($payment->customer->name, $sent->customer->name, 'Customer should have same name (payment ' . $index . q/)/);
+            is(
+                $payment->customer->email,
+                $sent->customer->email,
+                'Customer should have same email (payment ' . $index . q/)/,
+            );
+            is(
+                $payment->customer->external_id,
+                $sent->customer->external_id,
+                'Customer should have same external_id (payment ' . $index . q/)/,
+            );
+            is(
+                $payment->customer->name,
+                $sent->customer->name,
+                'Customer should have same name (payment ' . $index . q/)/,
+            );
         }
 
         is($index, 2, 'Should have made 2 loop');
@@ -147,7 +172,7 @@ sub list : Tests(38) {
         my $list = Stancer::Payment->list({order_id => '1337'});
         my $index = 0;
 
-        isa_ok($list, 'Stancer::Core::Iterator::Payment', 'Should return a Payment iterator');
+        isa_ok($list, 'Stancer::Core::Iterator::Payment', 'Stancer::Payment->list({order_id => $order_id})');
 
         while (my $payment = $list->next()) {
             fail('Should not find any payment');
@@ -175,7 +200,7 @@ sub list : Tests(38) {
             paym_BA8Ocj87XUgi3yn5dy0UPaDz
         );
 
-        isa_ok($list, 'Stancer::Core::Iterator::Payment', 'Should return a Payment iterator');
+        isa_ok($list, 'Stancer::Core::Iterator::Payment', 'Stancer::Payment->list({created => $created})');
 
         while (my $payment = $list->next()) {
             my $id = shift @payments;
@@ -313,7 +338,7 @@ sub send_global : Tests(49) {
         $payment->send();
 
         like($payment->id, qr/^paym_/sm, 'Should have an id');
-        isa_ok($payment->created, 'DateTime', 'Should have a creation date');
+        isa_ok($payment->created, 'DateTime', '$payment->created');
 
         like($card->id, qr/^card_/sm, 'Card should have an id');
         like($customer->id, qr/^cust_/sm, 'Customer should have an id');
@@ -363,13 +388,13 @@ sub send_global : Tests(49) {
         $payment->send();
 
         like($payment->id, qr/^paym_/sm, 'Should have an id');
-        isa_ok($payment->created, 'DateTime', 'Should have a creation date');
+        isa_ok($payment->created, 'DateTime', '$payment->created');
 
         like($card->id, qr/^card_/sm, 'Card should have an id');
         like($customer->id, qr/^cust_/sm, 'Customer should have an id');
         is($customer->id, $customer_id, 'Customer should be recovered from previous call');
 
-        isa_ok($payment->auth, 'Stancer::Auth', 'Should have a auth object');
+        isa_ok($payment->auth, 'Stancer::Auth', '$payment->auth');
         is($payment->auth->status, Stancer::Auth::Status::AVAILABLE, 'Auth should be available');
         like($payment->auth->redirect_url, qr/^https:\/\/3ds[.]/sm, 'Should have an authentication redirection URL');
         is($payment->auth->return_url, $return_url, 'Should have an authentication return URL');
@@ -402,14 +427,14 @@ sub send_global : Tests(49) {
         $payment->send();
 
         like($payment->id, qr/^paym_/sm, 'Should have an id');
-        isa_ok($payment->created, 'DateTime', 'Should have a creation date');
+        isa_ok($payment->created, 'DateTime', '$payment->created');
 
         like($customer->id, qr/^cust_/sm, 'Customer should have an id');
 
         is($payment->method, undef, 'Should not have a method');
         is($payment->status, undef, 'Should not have a status');
 
-        isa_ok($payment->auth, 'Stancer::Auth', 'Should have a auth object');
+        isa_ok($payment->auth, 'Stancer::Auth', '$payment->auth');
         is($payment->auth->status, Stancer::Auth::Status::REQUESTED, 'Auth should be requested');
         is($payment->auth->redirect_url, undef, 'Should have an authentication redirection URL');
         is($payment->auth->return_url, undef, 'Should have an authentication return URL');
@@ -440,7 +465,7 @@ sub send_global : Tests(49) {
         $payment->send();
 
         like($payment->id, qr/^paym_/sm, 'Should have an id');
-        isa_ok($payment->created, 'DateTime', 'Should have a creation date');
+        isa_ok($payment->created, 'DateTime', '$payment->created');
 
         like($customer->id, qr/^cust_/sm, 'Customer should have an id');
 
@@ -472,7 +497,7 @@ sub send_global : Tests(49) {
         $payment->send();
 
         like($payment->id, qr/^paym_/sm, 'Should have an id');
-        isa_ok($payment->created, 'DateTime', 'Should have a creation date');
+        isa_ok($payment->created, 'DateTime', '$payment->created');
 
         like($customer->id, qr/^cust_/sm, 'Customer should have an id');
 
@@ -498,7 +523,11 @@ sub send_global : Tests(49) {
         $payment->status(Stancer::Payment::Status::AUTHORIZE);
         $payment->send();
 
-        is($payment->status, Stancer::Payment::Status::AUTHORIZED, 'At least, we have updated the status, can we do it again ?');
+        is(
+            $payment->status,
+            Stancer::Payment::Status::AUTHORIZED,
+            'At least, we have updated the status, can we do it again ?',
+        );
 
         $payment->status(Stancer::Payment::Status::CAPTURE);
         $payment->send();
@@ -544,7 +573,7 @@ sub send_global : Tests(49) {
         $payment->send();
 
         like($payment->id, qr/^paym_/sm, 'Should have an id');
-        isa_ok($payment->created, 'DateTime', 'Should have a creation date');
+        isa_ok($payment->created, 'DateTime', '$payment->created');
 
         like($card->id, qr/^card_/sm, 'Card should have an id');
         like($customer->id, qr/^cust_/sm, 'Customer should have an id');
@@ -563,7 +592,7 @@ sub send_global : Tests(49) {
         my $message = 'Payment already exists, duplicate unique_id';
 
         throws_ok { $duplicate->send() } 'Stancer::Exceptions::Http::Conflict', 'Payment already exists';
-        like($@->message, qr/^$message [(]paym_\w{24}[)]$/sm, 'Should indicate the error');
+        like($EVAL_ERROR->message, qr/^$message [(]paym_\w{24}[)]$/sm, 'Should indicate the error');
     }
 
     { # 4 tests
@@ -586,7 +615,7 @@ sub send_global : Tests(49) {
         $payment->send();
 
         like($payment->id, qr/^paym_/sm, 'Should have an id');
-        isa_ok($payment->created, 'DateTime', 'Should have a creation date');
+        isa_ok($payment->created, 'DateTime', '$payment->created');
 
         is($card->id, $card_id, 'Card should have the same id');
         is($customer->id, $customer_id, 'Customer should have the same id');
